document.addEventListener('DOMContentLoaded', () => {
  const voteButtons = document.querySelectorAll('.vote-btn');
  const votes = new Map();

  // Initialize votes
  document.querySelectorAll('.destination-card').forEach(card => {
    votes.set(card.dataset.destination, 0);
  });

  // Handle voting
  voteButtons.forEach(button => {
    button.addEventListener('click', (e) => {
      const card = e.target.closest('.destination-card');
      const destination = card.dataset.destination;
      const currentVotes = votes.get(destination) || 0;
      
      // Increment votes
      votes.set(destination, currentVotes + 1);
      
      // Update display
      card.querySelector('.vote-count').textContent = votes.get(destination);
      
      // Animate button
      button.classList.add('voted');
      setTimeout(() => button.classList.remove('voted'), 300);
      
      // Update chart
      updateResults();
    });
  });

  function updateResults() {
    const resultsChart = document.querySelector('.results-chart');
    resultsChart.innerHTML = '';
    
    votes.forEach((count, destination) => {
      const percentage = calculatePercentage(count);
      const bar = document.createElement('div');
      bar.className = 'result-bar';
      bar.innerHTML = `
        <div class="bar-label">${destination}</div>
        <div class="bar-fill" style="width: ${percentage}%"></div>
        <div class="bar-value">${count} votes (${percentage}%)</div>
      `;
      resultsChart.appendChild(bar);
    });
  }

  function calculatePercentage(count) {
    const total = Array.from(votes.values()).reduce((sum, current) => sum + current, 0);
    return total === 0 ? 0 : Math.round((count / total) * 100);
  }

  // Initialize results chart
  updateResults();
});
